@@ -1,14 +1,18 @@
 
 package Sub::Inject;
-$Sub::Inject::VERSION = '0.2_1'; # TRIAL
-
-$Sub::Inject::VERSION = '0.21';# ABSTRACT: Inject subroutines into a lexical scope
+$Sub::Inject::VERSION = '0.3.0';
+# ABSTRACT: Inject subroutines into a lexical scope
 
 use 5.018;
 
-use XSLoader 0.20;
+require XSLoader;
 XSLoader::load(__PACKAGE__);
 
+sub sub_inject {
+    @_ = %{ $_[0] } if @_ == 1 && ref $_[0] eq 'HASH';
+    goto &_sub_inject;
+}
+
 1;
 
 #pod =encoding utf8
@@ -79,6 +83,7 @@ XSLoader::load(__PACKAGE__);
 #pod
 #pod     sub_inject($name, $code);
 #pod     sub_inject($name1, $code1, $name2, $code2);
+#pod     sub_inject(\%subs);
 #pod
 #pod Injects C<$code> as a lexical subroutine named C<$name>
 #pod into the currently compiling scope. The same applies
@@ -114,7 +119,7 @@ Sub::Inject - Inject subroutines into a lexical scope
 
 =head1 VERSION
 
-version 0.2_1
+version 0.3.0
 
 =head1 SYNOPSIS
 
@@ -182,6 +187,7 @@ The reference aliasing operation means no copy is done
 
     sub_inject($name, $code);
     sub_inject($name1, $code1, $name2, $code2);
+    sub_inject(\%subs);
 
 Injects C<$code> as a lexical subroutine named C<$name>
 into the currently compiling scope. The same applies
